@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from datetime import datetime
+from datetime import datetime, timezone
 from functools import total_ordering
 from enum import Enum, unique
 
@@ -13,6 +13,21 @@ class TransportType(str, Enum):
     TRAIN = "rail"
     BUS = "bus"
 
+@unique
+class TransportStatus(str, Enum):
+    """
+    Represents the status of a transport
+    """
+    ON_TIME = "onTime"
+    MISSED = "missed"
+    ARRIVED = "arrived"
+    NOT_EXPECTED = "notExpected"
+    DELAYED = "delayed"
+    EARLY = "early"
+    CANCELLED = "cancelled"
+    NO_REPORT = "noReport"
+    UNKNOWN = "unknown"
+
 @dataclass(frozen=True)
 class LineData:
     """
@@ -55,18 +70,20 @@ class InfoData:
     def from_json(data: dict):
         name = ""
         message = ""
-        for i in data["Content"]["Message"]:
-            if i["MessageType"] == "TEXT_ONLY":
-                message = i["MessageText"]["value"]
-            if i["MessageType"] == "SHORT_MESSAGE":
-                name = i["MessageText"]["value"]
+        if "Message" in data["Content"]:
+            for i in data["Content"]["Message"]:
+                if "MessageType" in i:
+                    if i["MessageType"] == "TEXT_ONLY":
+                        message = i["MessageText"]["value"]
+                    if i["MessageType"] == "SHORT_MESSAGE":
+                        name = i["MessageText"]["value"]
 
         return InfoData(
             name=name,
             id=data.get("id"),
             message=message,
-            start_time=datetime.strptime(data.get("RecordedAtTime"), '%Y-%m-%dT%H:%M:%S.%fZ'),
-            end_time=datetime.strptime(data.get("ValidUntilTime"), '%Y-%m-%dT%H:%M:%S.%fZ'),
+            start_time=datetime.strptime(data.get("RecordedAtTime"), '%Y-%m-%dT%H:%M:%S.%fZ').replace(tzinfo=timezone.utc),
+            end_time=datetime.strptime(data.get("ValidUntilTime"), '%Y-%m-%dT%H:%M:%S.%fZ').replace(tzinfo=timezone.utc),
             type=data["InfoChannelRef"]["value"],
             severity=data.get("InfoMessageVersion")
         )
@@ -84,6 +101,9 @@ class TrafficData:
     direction: str
     schedule: datetime
     retarted: bool
+    at_stop: bool
+    platform: str
+    status: str
 
     @staticmethod
     def from_json(data: dict):
@@ -97,17 +117,42 @@ class TrafficData:
         except KeyError:
             note = ""
 
-        if "ExpectedArrivalTime" not in data["MonitoredVehicleJourney"]["MonitoredCall"]:
+        sch = None
+        if "ExpectedArrivalTime" in data["MonitoredVehicleJourney"]["MonitoredCall"]:
+            sch = datetime.strptime(data["MonitoredVehicleJourney"]["MonitoredCall"]["ExpectedArrivalTime"], '%Y-%m-%dT%H:%M:%S.%fZ').replace(tzinfo=timezone.utc)
+        elif "ExpectedDepartureTime" in data["MonitoredVehicleJourney"]["MonitoredCall"]:
+            sch = datetime.strptime(data["MonitoredVehicleJourney"]["MonitoredCall"]["ExpectedDepartureTime"], '%Y-%m-%dT%H:%M:%S.%fZ').replace(tzinfo=timezone.utc)
+        else:
             return None
 
+        try:
+            atstop = data["MonitoredVehicleJourney"]["MonitoredCall"]["VehicleAtStop"]
+        except KeyError:
+            atstop = None
+
+        try:
+            plat = data["MonitoredVehicleJourney"]["MonitoredCall"]["ArrivalPlatformName"]["value"]
+        except KeyError:
+            plat = ""
+
+        if "ArrivalStatus" in data["MonitoredVehicleJourney"]["MonitoredCall"]:
+            status = TransportStatus(data["MonitoredVehicleJourney"]["MonitoredCall"]["ArrivalStatus"])
+        elif "DepartureStatus" in data["MonitoredVehicleJourney"]["MonitoredCall"]:
+            status = TransportStatus(data["MonitoredVehicleJourney"]["MonitoredCall"]["DepartureStatus"])
+        else:
+            status = TransportStatus.UNKNOWN
+
         return TrafficData(
             line_id=data["MonitoredVehicleJourney"]["LineRef"]["value"],
             note=note,
             destination_name=data["MonitoredVehicleJourney"]["DestinationName"][0]["value"],
             destination_id=data["MonitoredVehicleJourney"]["DestinationRef"]["value"],
             direction=dir,
-            schedule=datetime.strptime(data["MonitoredVehicleJourney"]["MonitoredCall"]["ExpectedArrivalTime"], '%Y-%m-%dT%H:%M:%S.%fZ'),
-            retarted=data["MonitoredVehicleJourney"]["MonitoredCall"].get("ArrivalStatus") in [None, "onTime"]
+            schedule=sch,
+            retarted=status not in [TransportStatus.ON_TIME, TransportStatus.ARRIVED, TransportStatus.UNKNOWN],
+            at_stop=atstop,
+            platform=plat,
+            status=status
         )
 
     def __eq__(self, other):
